var assert = require('assert'),
    s1 = require('testingey').createSuite('Generic tests'),
    s2 = require('testingey').createSuite('Search functionality tests'),
    indexer = require('../lib/indexer'),
    indices = null,
    users = null;

s1.setUp(function () {
  
  users = [
    { username: 'jaydee', country: 'PH', age: 32, type: 0 },
    { username: 'sheryl', country: 'PH', age: 33, type: 0 },
    { username: 'juliane', country: 'PH', age: 0, type: 1 }
  ];
  
  indices = {
    username: indexer.create('username'),
    country: indexer.create('country'),
    age: indexer.create({ name: 'age', type: 'numeric' }),
    type: indexer.create({ name: 'type', type: 'numeric' })
  };

});

s1.spec('Testing index.add()', function () {
  users.forEach(function (user) {
    indices['username'].add(user.username, user.username);
    assert.equal(indices['username'].search(user.username).length, 1);
  });
});

s1.spec('Testing index.all()', function () {
  var matches = indices['username'].all(2, 1);
  assert.equal(matches.length, 2);
});

s1.spec('Testing index.remove()', function () {
  users.forEach(function (user) {
    indices['username'].remove(user.username);
    assert.equal(indices['username'].search(user.username).length, 0);
  });
});

s1.spec('Testing index.search()', function () {
  
  users.forEach(function (user) {
    indices['type'].add(user.type, user.username);
  });
  
  var matches = indices['type'].search(1);
  assert.equal(matches.length, 1);
  assert.equal(matches[0], 'juliane');

  indices['type'].remove('juliane');

  matches = indices['type'].search(1);
  assert.equal(matches.length, 0);
});

s2.setUp(function () {
  nIndex = indexer.create({ name: 'age', type: 'numeric' });
  for (var i = 0; i < 1000; ++i) {
    nIndex.add(i, 'key-' + i);
  }
});

s2.spec('Testing ranged search', function () {
  var keys = nIndex.search({ min: 8, max: 8 });
  assert.equal(keys.length, 1);
  assert.equal(keys[0], 'key-8');
});

s2.spec('Testing single value search', function () {
  var keys = nIndex.search(5);
  assert.equal(keys.length, 1);
  assert.equal(keys[0], 'key-5');
});

s2.spec('Testing multiple value search', function () {
  var keys = nIndex.search([5, 3, 6, 8, 2, 9]);
  assert.equal(keys.length, 6);
});

s2.tearDown(function () {
  nIndex.flush();
});

s1.run();
s2.run();
